/* ------------------------------------------------------------------------
   (C) Copyright Marxmeier Software AG 2009-2014

   Project:  Eloquence JDLG Plugin Interface
   File:     Dual_edit_demo.java
   Function: JDLG Plugin Demo
   $Id: Dual_edit_demo.java,v 1.1 2014/04/09 11:56:27 rhg Exp $

   This class implements a JDLG plugin containing two JTextField elements
   arranged in a GridLayout panel.

   It demonstrates the following aspects of the JDLG Plugin API:
   - Using a peer object different from the plugin object.
   - Managing the focus peer object.
   - Disabling the default key listener, installing a key listener
     on the peer object.
   - Adjusting the font of the contained elements.

   Edit history:
   2009-09-25, rhg  - creation
 ------------------------------------------------------------------------ */

package com.eloquence.plugin;

import com.eloquence.api.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class Dual_edit_demo
   implements Plugin, KeyListener, FocusListener
{
   private Jdlg jdlg;
   private JTextField leftEdit;
   private JTextField rightEdit;
   private Component focusPeer = null;
   private JPanel panel;

   // Plugin

   public Component onCreate(Jdlg jdlg)
   {
      if (!jdlg.requiresApiVersion(1, 0))
         return null;

      this.jdlg = jdlg;
      jdlg.defaultKeyboardHandler(false);

      leftEdit = new JTextField();
      leftEdit.addKeyListener(this);
      leftEdit.addFocusListener(this);
      leftEdit.setFocusTraversalKeysEnabled(false);

      rightEdit = new JTextField();
      rightEdit.addKeyListener(this);
      rightEdit.addFocusListener(this);
      rightEdit.setFocusTraversalKeysEnabled(false);

      panel = new JPanel();
      panel.add(leftEdit);
      panel.add(rightEdit);
      panel.setLayout(new GridLayout(1, 2));
      panel.setFocusTraversalKeysEnabled(false);
      panel.addKeyListener(this);
      return panel;
   }

   public void onClone(Plugin clone)
   {
   }

   public void onDispose()
   {
   }

   public void onEloq2Swing()
   {
   }

   public void onSwing2Eloq()
   {
   }

   public boolean onSet(String attribute,
                        java.util.List index,
                        UnifiedData data)
   {
      return false;
   }

   public UnifiedData onGet(String attribute,
                            java.util.List index)
   {
      return null;
   }

   public void onFontModified(Font font)
   {
      leftEdit.setFont(font);
      rightEdit.setFont(font);
   }

   public boolean isFocusable()
   {
      return true;
   }

   public void onFocusReceived()
   {
   }

   public void onFocusLost()
   {
   }

   public Component onGetFocusPeer()
   {
      if (focusPeer == null)
         focusPeer = leftEdit;
      return focusPeer;
   }

   public void onTabFocus(boolean toNext)
   {
      focusPeer = toNext ? leftEdit : rightEdit;
   }

   public boolean fireRuleOnLosingFocus()
   {
      return false;
   }

   public boolean onRuleOverride()
   {
      return false;
   }

   public boolean allowRMBR()
   {
      return true;
   }

   // KeyListener

   public void keyPressed(KeyEvent event)
   {
      if (event.getKeyCode() == KeyEvent.VK_TAB)
      {
         if (event.isShiftDown())
         {
            if (event.getComponent() == rightEdit)
            {
               leftEdit.requestFocusInWindow();
               event.consume();
               return;
            }
         }
         else if (event.getComponent() == leftEdit)
         {
            rightEdit.requestFocusInWindow();
            event.consume();
            return;
         }
      }

      jdlg.getKeyboardListener().keyPressed(event);
   }

   public void keyTyped(KeyEvent event)
   {
      jdlg.getKeyboardListener().keyTyped(event);
   }

   public void keyReleased(KeyEvent event)
   {
      jdlg.getKeyboardListener().keyReleased(event);
   }

   // FocusListener

   public void focusGained(FocusEvent event)
   {
      focusPeer = event.getComponent();
   }

   public void focusLost(FocusEvent event)
   {
   }
}
