/* ------------------------------------------------------------------------
   (C) Copyright Marxmeier Software AG 2009-2014

   Project:  Eloquence JDLG Plugin Interface
   File:     Label_demo.java
   Function: JDLG Plugin Demo
   $Id: Label_demo.java,v 1.1 2014/04/09 11:56:27 rhg Exp $

   This class implements a basic JDLG plugin wrapping a JLabel.

   It demonstrates the following aspects of the JDLG Plugin API:
   - Plugin and peer objects are identical.
   - Cloning peer object properties.
   - Setting peer object properties in onEloq2swing().
   - Setting and getting attribute values.

   Edit history:
   2009-04-08, rhg  - creation
 ------------------------------------------------------------------------ */

package com.eloquence.plugin;

import com.eloquence.api.*;
import java.awt.*;
import javax.swing.*;

public class Label_demo
   extends JLabel
   implements Plugin
{
   private Jdlg jdlg;
   private String text = "";
   private int halign = CENTER, valign = CENTER;
   private boolean modified = true;

   public Component onCreate(Jdlg jdlg)
   {
      if (!jdlg.requiresApiVersion(1, 0))
         return null;

      this.jdlg = jdlg;
      return this;
   }

   public void onClone(Plugin clone)
   {
      Label_demo cloneObj = (Label_demo)clone;
      cloneObj.text = text;
      cloneObj.halign = halign;
      cloneObj.valign = valign;
   }

   public void onDispose()
   {
   }

   public void onEloq2Swing()
   {
      if (modified)
      {
         modified = false;
         setText(text);
         setHorizontalAlignment(halign);
         setVerticalAlignment(valign);
      }
   }

   public void onSwing2Eloq()
   {
   }

   public boolean onSet(String attribute,
                        java.util.List index,
                        UnifiedData data)
   {
      if (index != null && index.size() != 0)
         return false;

      if (attribute.equals("text"))
      {
         if (!data.isStringData())
            return false;

         text = data.getStringData();
         return true;
      }

      if (attribute.equals("halign"))
      {
         if (!data.isStringData())
            return false;

         String align = data.getStringData();
         if (align.equalsIgnoreCase("left"))
            halign = LEFT;
         else if (align.equalsIgnoreCase("center"))
            halign = CENTER;
         else if (align.equalsIgnoreCase("right"))
            halign = RIGHT;
         else
            return false;

         return true;
      }

      if (attribute.equals("valign"))
      {
         if (!data.isStringData())
            return false;

         String align = data.getStringData();
         if (align.equalsIgnoreCase("top"))
            valign = TOP;
         else if (align.equalsIgnoreCase("center"))
            valign = CENTER;
         else if (align.equalsIgnoreCase("bottom"))
            valign = BOTTOM;
         else
            return false;

         return true;
      }

      return false;
   }

   public UnifiedData onGet(String attribute,
                            java.util.List index)
   {
      if (index != null && index.size() != 0)
         return null;

      if (attribute.equals("text"))
         return new UnifiedData(text);

      if (attribute.equals("halign"))
      {
         String align;
         switch (halign)
         {
            case LEFT:
               align = "left";
               break;
            case CENTER:
               align = "center";
               break;
            case RIGHT:
               align = "right";
               break;
            default:
               return null;
         }

         return new UnifiedData(align);
      }

      if (attribute.equals("valign"))
      {
         String align;
         switch (valign)
         {
            case TOP:
               align = "top";
               break;
            case CENTER:
               align = "center";
               break;
            case BOTTOM:
               align = "bottom";
               break;
            default:
               return null;
         }

         return new UnifiedData(align);
      }

      return null;
   }

   public void onFontModified(Font font)
   {
   }

   public boolean isFocusable()
   {
      return false;
   }

   public void onFocusReceived()
   {
   }

   public void onFocusLost()
   {
   }

   public Component onGetFocusPeer()
   {
      return null;
   }

   public void onTabFocus(boolean toNext)
   {
   }

   public boolean fireRuleOnLosingFocus()
   {
      return false;
   }

   public boolean onRuleOverride()
   {
      return false;
   }

   public boolean allowRMBR()
   {
      return true;
   }
}
